formfactor (ff)
===============

.. automodule:: jscatter.formfactor
    :noindex:
   
Form Factors
------------

**General**

.. autosummary::
    beaucage
    genGuinier
    guinier
    guinierPorod
    guinierPorod3d
    gaussianChain
    ringPolymer
    wormlikeChain

----

**Sphere, Ellipsoid, Cylinder, Cube, CoreShell,..**

.. autosummary::
    sphere
    ellipsoid
    cylinder
    disc
    cuboid
    superball
    sphereCoreShell
    sphereFuzzySurface
    sphereGaussianCorona
    sphereCoreShellGaussianCorona
    inhomogeneousSphere
    fuzzyCylinder

----

**Multi shell models**

.. autosummary::
    multilayer
    multiShellSphere
    multiShellEllipsoid
    multiShellDisc
    multiShellCylinder
    multilamellarVesicles

----

**Other**

.. autosummary::
    pearlNecklace
    linearPearls
    teubnerStrey
    ellipsoidFilledCylinder
    decoratedCoreShell


Cloud of scatterers
-------------------
.. automodule:: jscatter.cloudscattering
    :noindex:

.. autosummary::
    ~jscatter.cloudscattering.cloudScattering
    ~jscatter.cloudscattering.orientedCloudScattering

------

.. automodule:: jscatter.formfactor
    :members:
    :undoc-members:
    :show-inheritance:
   

.. automodule:: jscatter.cloudscattering
    :members:


   
   